==> jc-1.4.0.tar.gz: java/lang/InstantiationException.h <==
// public class java.lang.InstantiationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class b09d021696f0bbb java_lang_InstantiationException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_lang_InstantiationException_H_
#define _JC_java_lang_InstantiationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_InstantiationException$sub_refs	_jc_java_lang_InstantiationException$sub_refs;
typedef struct _jc_java_lang_InstantiationException$sub_nonrefs	_jc_java_lang_InstantiationException$sub_nonrefs;
typedef struct _jc_java_lang_InstantiationException$refs	_jc_java_lang_InstantiationException$refs;
typedef struct _jc_java_lang_InstantiationException$nonrefs	_jc_java_lang_InstantiationException$nonrefs;
typedef struct _jc_java_lang_InstantiationException$object	_jc_java_lang_InstantiationException$object;

typedef struct _jc_java_lang_InstantiationException$fields_struct	_jc_java_lang_InstantiationException$fields_struct;
typedef const struct _jc_java_lang_InstantiationException$vmethods	_jc_java_lang_InstantiationException$vmethods;
typedef const struct _jc_java_lang_InstantiationException$vtable	_jc_java_lang_InstantiationException$vtable;
typedef const struct _jc_java_lang_InstantiationException$vtype	_jc_java_lang_InstantiationException$vtype;

// Class fields structure
struct _jc_java_lang_InstantiationException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_InstantiationException$fields_struct _jc_java_lang_InstantiationException$class_fields;

// Constructors
extern void _jc_java_lang_InstantiationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_InstantiationException$object *);
extern void _jc_java_lang_InstantiationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_InstantiationException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_InstantiationException$vmethods {
};

// Vtable
struct _jc_java_lang_InstantiationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_InstantiationException$vmethods	java_lang_InstantiationException;
};

// Vtype
struct _jc_java_lang_InstantiationException$vtype {
	_jc_type			type;
	_jc_java_lang_InstantiationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_InstantiationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_InstantiationException$refs {
    _jc_java_lang_InstantiationException$sub_refs	java_lang_InstantiationException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_InstantiationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_InstantiationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_InstantiationException$sub_nonrefs	java_lang_InstantiationException;
};

// Object instance structure
struct _jc_java_lang_InstantiationException$object {
	_jc_java_lang_InstantiationException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_InstantiationException$vtype	*vtype;
	_jc_java_lang_InstantiationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_InstantiationException$vtype _jc_java_lang_InstantiationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_InstantiationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_InstantiationException$class_object;

#endif	/* _JC_java_lang_InstantiationException_H_ */

==> jc-1.4.6.tar.gz: java/lang/InstantiationException.h <==
// public class java.lang.InstantiationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class b09d021696f0bbb java_lang_InstantiationException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_lang_InstantiationException_H_
#define _JC_java_lang_InstantiationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_InstantiationException$sub_refs	_jc_java_lang_InstantiationException$sub_refs;
typedef struct _jc_java_lang_InstantiationException$sub_nonrefs	_jc_java_lang_InstantiationException$sub_nonrefs;
typedef struct _jc_java_lang_InstantiationException$refs	_jc_java_lang_InstantiationException$refs;
typedef struct _jc_java_lang_InstantiationException$nonrefs	_jc_java_lang_InstantiationException$nonrefs;
typedef struct _jc_java_lang_InstantiationException$object	_jc_java_lang_InstantiationException$object;

typedef struct _jc_java_lang_InstantiationException$fields_struct	_jc_java_lang_InstantiationException$fields_struct;
typedef const struct _jc_java_lang_InstantiationException$vmethods	_jc_java_lang_InstantiationException$vmethods;
typedef const struct _jc_java_lang_InstantiationException$vtable	_jc_java_lang_InstantiationException$vtable;
typedef const struct _jc_java_lang_InstantiationException$vtype	_jc_java_lang_InstantiationException$vtype;

// Class fields structure
struct _jc_java_lang_InstantiationException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_InstantiationException$fields_struct _jc_java_lang_InstantiationException$class_fields;

// Constructors
extern void _jc_java_lang_InstantiationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_InstantiationException$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_InstantiationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_InstantiationException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_InstantiationException$vmethods {
};

// Vtable
struct _jc_java_lang_InstantiationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_InstantiationException$vmethods	java_lang_InstantiationException;
};

// Vtype
struct _jc_java_lang_InstantiationException$vtype {
	_jc_type			type;
	_jc_java_lang_InstantiationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_InstantiationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_InstantiationException$refs {
    _jc_java_lang_InstantiationException$sub_refs	java_lang_InstantiationException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_InstantiationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_InstantiationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_InstantiationException$sub_nonrefs	java_lang_InstantiationException;
};

// Object instance structure
struct _jc_java_lang_InstantiationException$object {
	_jc_java_lang_InstantiationException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_InstantiationException$vtype	*vtype;
	_jc_java_lang_InstantiationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_InstantiationException$vtype _jc_java_lang_InstantiationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_InstantiationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_InstantiationException$class_object;

#endif	/* _JC_java_lang_InstantiationException_H_ */
